@@ -323,8 +323,8 @@ void pdl_magic_thread_cast(pdl *it,void (*func)(pdl_trans *),pdl_trans *t, pdl_t
 	tp = malloc(sizeof(pthread_t) * thread->mag_nthr);
 	tparg = malloc(sizeof(*tparg) * thread->mag_nthr);
 	pthread_key_create(&(ptr->key),NULL);
-	/* if(TVERB) printf("CREATING THREADS, ME: %d, key: %d\n",pthread_self(), ptr->key); */
-	if(TVERB) printf("CREATING THREADS, ME: TBD, key: %d\n", ptr->key);
+
+	if(TVERB) printf("CREATING THREADS, ME: TBD, key: %ld\n", (unsigned long)(ptr->key));
 
 	/* Get the pthread ID of this main thread we are in.
 	 *	Any barf, warn, etc calls in the spawned pthreads can use this
@@ -342,13 +342,15 @@ void pdl_magic_thread_cast(pdl *it,void (*func)(pdl_trans *),pdl_trans *t, pdl_t
             die("Unable to create pthreads!");
         }
     }
-	/* if(TVERB) printf("JOINING THREADS, ME: %d, key: %d\n",pthread_self(), ptr->key); */
-	if(TVERB) printf("JOINING THREADS, ME: TBD, key: %d\n", ptr->key);
+
+    if(TVERB) printf("JOINING THREADS, ME: TBD, key: %ld\n", (unsigned long)(ptr->key));
+
 	for(i=0; i<thread->mag_nthr; i++) {
 		pthread_join(tp[i], NULL);
 	}
-	/* if(TVERB) printf("FINISHED THREADS, ME: %d, key: %d\n",pthread_self(), ptr->key); */
-	if(TVERB) printf("FINISHED THREADS, ME: TBD, key: %d\n", ptr->key);
+
+	if(TVERB) printf("FINISHED THREADS, ME: TBD, key: %ld\n", (unsigned long)(ptr->key));
+
 	pthread_key_delete((ptr->key));
 
 	/* Remove pthread magic if we created in this function */
@@ -502,14 +504,14 @@ int pdl_pthread_barf_or_warn(const char* pat, int iswarn, va_list *args){ return
  */
 
 
-void pdl_delete_mmapped_data(pdl *p, int param)
+void pdl_delete_mmapped_data(pdl *p, Size_t param)
 {
 	if(!p) {return;}
 	if(!p->data) {return;}
 #ifdef USE_MMAP
 	munmap(p->data, param);
 #else
-        croak("internal error: trying to delete mmaped data on unsupported platform");
+      /*  croak("internal error: trying to delete mmaped data on unsupported platform"); */
 #endif
 	p->data = 0;
 }
@@ -526,7 +528,7 @@ struct pdl_magic_vtable deletedatamagic_vtable = {
 	NULL
 };
 
-void pdl_add_deletedata_magic(pdl *it, void (*func)(pdl *, int param), int param)
+void pdl_add_deletedata_magic(pdl *it, void (*func)(pdl *, Size_t param), Size_t param)
 {
 	pdl_magic_deletedata *ptr = malloc(sizeof(pdl_magic_deletedata));
 	ptr->what = PDL_MAGIC_DELETEDATA;
